@@ -24,5 +24,15 @@
 # *
 # **************************************************************************
 
+from pyworkflow.tests import DataSet
+
 from .test_protocols_cistem import TestCtffind4
 from .test_protocols_cistem_movies import TestMoviesBase, TestUnblur
+from .test_protocols_cistem_ts import TestCtffind4Ts
+
+
+DataSet(name='tutorialDataImodCTF',
+        folder='tutorialDataImodCTF',
+        files={
+            'tsCtf1': 'WTI042413_1series4.st'
+        })
